@@ -2,23 +2,23 @@
 use crate::serialize::Type;
 
 /// `$ mlmdquery {get,count} context-types` options.
-#[derive(Debug, structopt::StructOpt)]
+#[derive(Debug, Clone, structopt::StructOpt, serde::Serialize, serde::Deserialize)]
 #[structopt(rename_all = "kebab-case")]
 pub struct ContextTypesOpt {
     /// Database URL.
     #[structopt(long, env = "MLMD_DB", hide_env_values = true)]
+    #[serde(skip)]
     pub db: String,
 }
 
 impl ContextTypesOpt {
     /// `$ mlmdquery count context-types` implementation.
-    pub async fn count(&self) -> anyhow::Result<usize> {
-        Ok(self.get().await?.len())
+    pub async fn count(&self, store: &mut mlmd::MetadataStore) -> anyhow::Result<usize> {
+        Ok(self.get(store).await?.len())
     }
 
     /// `$ mlmdquery get context-types` implementation.
-    pub async fn get(&self) -> anyhow::Result<Vec<Type>> {
-        let mut store = mlmd::MetadataStore::connect(&self.db).await?;
+    pub async fn get(&self, store: &mut mlmd::MetadataStore) -> anyhow::Result<Vec<Type>> {
         let types = store.get_context_types().execute().await?;
         Ok(types.into_iter().map(Type::from).collect())
     }
